==> qore-2.0.0.tar.bz2: qore-2.0.0/docs/modules/ServerSentEventHandler/html/class_server_sent_event_handler_1_1_server_sent_event_connection.js <==
var class_server_sent_event_handler_1_1_server_sent_event_connection =
[
    [ "connectionClosed", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a101074a000ea3782752f261ad62b5aa9", null ],
    [ "constructor", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#af8a6f74078e3f2dfa0a16f6ab332b657", null ],
    [ "flush", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a5112871c2ab9dcf4bf090cb09ce42c99", null ],
    [ "pollData", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a1e0f699132f029aec9fbd3c9d25d23f1", null ],
    [ "pollDataImmediate", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a5e8d4b8a501ecfb49273cd43ce2af5f0", null ],
    [ "queue", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a73a0e9cf2bb8e8bb075a254ac941c372", null ],
    [ "registered", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#aee0cac48d1e654490419a56f1e945f87", null ],
    [ "send", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a7a04751571decae5b3fa166fc8168ea1", null ],
    [ "sendEncoded", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a3a9f3de10909df1cbc002acbf161e40c", null ],
    [ "stop", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a4c5cfaaacf3f607435bfb6b8ea4ed9f7", null ],
    [ "cid", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a4eb2da82fc7abc6f570624f5db8629b0", null ],
    [ "handler", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a948c5c7bb6067719ae4ea8d97590f590", null ],
    [ "sock", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#aea91be49a3b46d93b32bc5f70d5e0da0", null ],
    [ "stop_flag", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#aabcb93d7de9ebbbf94753f00d7125d48", null ],
    [ "tid", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a755362da04b1ab0bce28d6be4e32c1bc", null ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/modules/ServerSentEventHandler/html/class_server_sent_event_handler_1_1_server_sent_event_connection.js <==
var class_server_sent_event_handler_1_1_server_sent_event_connection =
[
    [ "connectionClosed", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a101074a000ea3782752f261ad62b5aa9", null ],
    [ "constructor", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a439f3817b2a01405019695a44eb9f8b5", null ],
    [ "flush", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a5112871c2ab9dcf4bf090cb09ce42c99", null ],
    [ "pollData", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a1e0f699132f029aec9fbd3c9d25d23f1", null ],
    [ "pollDataImmediate", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a5e8d4b8a501ecfb49273cd43ce2af5f0", null ],
    [ "queue", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a73a0e9cf2bb8e8bb075a254ac941c372", null ],
    [ "registered", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#aee0cac48d1e654490419a56f1e945f87", null ],
    [ "send", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a7a04751571decae5b3fa166fc8168ea1", null ],
    [ "sendEncoded", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a3a9f3de10909df1cbc002acbf161e40c", null ],
    [ "stop", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a4c5cfaaacf3f607435bfb6b8ea4ed9f7", null ],
    [ "cid", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a4eb2da82fc7abc6f570624f5db8629b0", null ],
    [ "cx", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a0323fd37495e26e48dfa0ae1e48e3614", null ],
    [ "handler", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a948c5c7bb6067719ae4ea8d97590f590", null ],
    [ "hdr", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a0d4c01280e9b110621fe9a96f50b3075", null ],
    [ "sock", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#aea91be49a3b46d93b32bc5f70d5e0da0", null ],
    [ "stop_flag", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#aabcb93d7de9ebbbf94753f00d7125d48", null ],
    [ "tid", "class_server_sent_event_handler_1_1_server_sent_event_connection.html#a755362da04b1ab0bce28d6be4e32c1bc", null ]
];
